var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Directive, HostBinding, Input, Component, ViewChild, ElementRef, HostListener, Injectable, Injector, TemplateRef, ViewContainerRef, EventEmitter, OpaqueToken, } from '@angular/core';
import { ComponentPortal, TemplatePortal } from '../core/portal';
import { HostClasses } from '../core/classes';
export var MdaDialogArgs = new OpaqueToken('mdaDialogArgs');
var MdaDialog = (function () {
    function MdaDialog(injector) {
        this.injector = injector;
    }
    MdaDialog.prototype.open = function (component, args) {
        var dialog = new ComponentPortal(MdaDialogContainer, this.injector);
        var content;
        if (component instanceof TemplateRef) {
            if (args) {
                throw new Error('Cannot provide arguments to a template ref dialog');
            }
            content = new TemplatePortal(component, null);
        }
        else {
            content = new ComponentPortal(component, this.injector);
        }
        var dialogRef = new MdaDialogRef(function () {
            content.detach();
            dialog.detach();
        });
        var dialogRefProvider = { provide: MdaDialogRef, useValue: dialogRef };
        var dialogArgsProvider = { provide: MdaDialogArgs, useValue: args };
        dialog.inject(dialogRefProvider);
        if (content instanceof ComponentPortal) {
            content.inject(dialogRefProvider, dialogArgsProvider);
        }
        dialog.attach(document.body);
        dialog.instance.attachPortal(content);
        return dialogRef;
    };
    return MdaDialog;
}());
MdaDialog = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [Injector])
], MdaDialog);
export { MdaDialog };
var MdaDialogRef = (function () {
    function MdaDialogRef(destroyFn) {
        this.destroyFn = destroyFn;
        this.closed = new EventEmitter();
    }
    MdaDialogRef.prototype.close = function (value) {
        this.destroyFn();
        this.closed.emit(value);
    };
    return MdaDialogRef;
}());
export { MdaDialogRef };
var MdaDialogContainer = (function () {
    function MdaDialogContainer(elementRef, dialogRef, viewRef) {
        this.elementRef = elementRef;
        this.dialogRef = dialogRef;
        this.viewRef = viewRef;
    }
    MdaDialogContainer.prototype.onClick = function (target) {
        if (target === this.elementRef.nativeElement) {
            this.dialogRef.close();
        }
    };
    MdaDialogContainer.prototype.attachPortal = function (portal) {
        if (!portal.viewRef) {
            portal.viewRef = this.viewRef;
        }
        portal.attach(this.dialogElementRef.nativeElement);
    };
    MdaDialogContainer.prototype.ngAfterViewInit = function () { };
    return MdaDialogContainer;
}());
__decorate([
    ViewChild('dialog', { read: ElementRef }),
    __metadata("design:type", ElementRef)
], MdaDialogContainer.prototype, "dialogElementRef", void 0);
__decorate([
    HostListener('click', ['$event.target']),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [HTMLElement]),
    __metadata("design:returntype", void 0)
], MdaDialogContainer.prototype, "onClick", null);
MdaDialogContainer = __decorate([
    HostClasses('umd-dialog-container'),
    Component({
        selector: 'mda-dialog-container',
        template: "\n        <div #dialog class=\"umd-dialog\">\n        </div>\n    "
    }),
    __metadata("design:paramtypes", [ElementRef,
        MdaDialogRef,
        ViewContainerRef])
], MdaDialogContainer);
export { MdaDialogContainer };
var MdaDialogTitle = (function () {
    function MdaDialogTitle(elementRef) {
        this.elementRef = elementRef;
    }
    MdaDialogTitle.prototype.ngAfterViewInit = function () { };
    return MdaDialogTitle;
}());
MdaDialogTitle = __decorate([
    HostClasses('umd-dialog-title umd-dialog--includes-padding'),
    Directive({
        selector: 'mda-dialog-title'
    }),
    __metadata("design:paramtypes", [ElementRef])
], MdaDialogTitle);
export { MdaDialogTitle };
var MdaDialogContent = (function () {
    function MdaDialogContent(elementRef) {
        this.elementRef = elementRef;
    }
    MdaDialogContent.prototype.ngAfterViewInit = function () { };
    return MdaDialogContent;
}());
MdaDialogContent = __decorate([
    HostClasses('umd-dialog-content umd-dialog--includes-padding'),
    Directive({
        selector: 'mda-dialog-content'
    }),
    __metadata("design:paramtypes", [ElementRef])
], MdaDialogContent);
export { MdaDialogContent };
var MdaDialogActions = (function () {
    function MdaDialogActions() {
        this._ = true;
        this.isVertical = false;
    }
    Object.defineProperty(MdaDialogActions.prototype, "vertical", {
        set: function (vertical) {
            this.isVertical = vertical !== false && vertical !== null;
        },
        enumerable: true,
        configurable: true
    });
    return MdaDialogActions;
}());
__decorate([
    HostBinding('class.umd-dialog-actions'),
    __metadata("design:type", Object)
], MdaDialogActions.prototype, "_", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], MdaDialogActions.prototype, "vertical", null);
__decorate([
    HostBinding('class.umd-dialog-actions--vertical'),
    __metadata("design:type", Object)
], MdaDialogActions.prototype, "isVertical", void 0);
MdaDialogActions = __decorate([
    Directive({
        selector: 'mda-dialog-actions',
    })
], MdaDialogActions);
export { MdaDialogActions };
//# sourceMappingURL=dialog.js.map