export function HostClasses(classes) {
    return function (target) {
        var orig = target.prototype.ngAfterViewInit;
        target.prototype.ngAfterViewInit = function () {
            if (!this.elementRef) {
                console.warn("[" + target.name + "] Could not apply host classes, expected elementRef to be available.");
                return;
            }
            var element = this.elementRef.nativeElement;
            if (element) {
                classes
                    .split(' ')
                    .forEach(function (className) { return element.classList.add(className); });
            }
            if (orig) {
                orig.call(this);
            }
        };
    };
}
export function DynamicClass(classTemplate) {
    return function (target, key) {
        var initialised = false;
        var className;
        var value;
        Object.defineProperty(target, key, {
            get: function () { return value; },
            set: function (type) {
                if (type === value) {
                    return;
                }
                var element;
                if (initialised) {
                    element = this.elementRef.nativeElement;
                }
                element && element.classList.remove(className);
                className = classTemplate.replace('$1', type);
                element && element.classList.add(className);
                value = type;
            }
        });
        var orig = target.ngAfterViewInit;
        target.ngAfterViewInit = function () {
            if (!this.elementRef) {
                console.warn("[" + this.constructor.name + "] Could not apply dyanmic class, expected elementRef to be available.");
                return;
            }
            var element = this.elementRef.nativeElement;
            if (element && className) {
                element.classList.add(className);
            }
            initialised = true;
            if (orig) {
                orig.call(this);
            }
        };
    };
}
//# sourceMappingURL=classes.js.map