import { ReflectiveInjector, ComponentFactoryResolver, ApplicationRef } from '@angular/core';
var ComponentPortal = (function () {
    function ComponentPortal(component, viewRefOrInjector) {
        this.component = component;
        if (viewRefOrInjector.createComponent) {
            this.injector = viewRefOrInjector.parentInjector;
            this.viewRef = viewRefOrInjector;
        }
        else {
            this.injector = viewRefOrInjector;
        }
    }
    Object.defineProperty(ComponentPortal.prototype, "instance", {
        get: function () {
            return this.compRef.instance;
        },
        enumerable: true,
        configurable: true
    });
    ComponentPortal.prototype.inject = function () {
        var providers = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            providers[_i] = arguments[_i];
        }
        this.injector = ReflectiveInjector.resolveAndCreate(providers, this.injector);
    };
    ComponentPortal.prototype.attach = function (container) {
        container.appendChild(this.create());
    };
    ComponentPortal.prototype.detach = function () {
        this.destroy();
        this.compRef = null;
    };
    Object.defineProperty(ComponentPortal.prototype, "factoryResolver", {
        get: function () {
            return this.injector.get(ComponentFactoryResolver);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComponentPortal.prototype, "applicationRef", {
        get: function () {
            return this.injector.get(ApplicationRef);
        },
        enumerable: true,
        configurable: true
    });
    ComponentPortal.prototype.create = function () {
        var _this = this;
        if (!this.compRef) {
            var factory = this.factoryResolver.resolveComponentFactory(this.component);
            if (this.viewRef) {
                this.compRef = this.viewRef.createComponent(factory, this.viewRef.length, this.injector);
                this.destroy = function () { return _this.compRef.destroy(); };
            }
            else {
                this.compRef = factory.create(this.injector);
                this.applicationRef.attachView(this.compRef.hostView);
                this.destroy = function () {
                    _this.applicationRef.detachView(_this.compRef.hostView);
                    _this.compRef.destroy();
                };
            }
        }
        return this.compRef.hostView.rootNodes[0];
    };
    return ComponentPortal;
}());
export { ComponentPortal };
var TemplatePortal = (function () {
    function TemplatePortal(templateRef, viewRef, context) {
        if (context === void 0) { context = {}; }
        this.templateRef = templateRef;
        this.viewRef = viewRef;
        this.context = context;
    }
    TemplatePortal.prototype.attach = function (container) {
        if (!this.view) {
            this.view = this.viewRef.createEmbeddedView(this.templateRef, this.context);
        }
        this.view.rootNodes.forEach(function (node) { return container.appendChild(node); });
    };
    TemplatePortal.prototype.detach = function () {
        if (!this.view) {
            return;
        }
        this.view.rootNodes
            .filter(function (node) { return !!node.parentElement; })
            .forEach(function (node) { return node.parentElement.removeChild(node); });
        this.view.destroy();
        this.view = null;
    };
    return TemplatePortal;
}());
export { TemplatePortal };
//# sourceMappingURL=portal.js.map